@@ -84,7 +84,7 @@ static struct {
 } const ranges [] = {
 	{ "repeatkeys_delay_slide",	"repeatkeys_delay_spin",     500, 100, 1500,   10,
 	  "/desktop/gnome/peripherals/keyboard/delay" },
-	{ "repeatkeys_rate_slide",	"repeatkeys_rate_spin",      90,   10,  210,   10,
+	{ "repeatkeys_rate_slide",	"repeatkeys_rate_spin",      90,   10,  110,   10,
 	  "/desktop/gnome/peripherals/keyboard/rate" },
 	{ "bouncekeys_delay_slide",	"bouncekeys_delay_spin",       0,   0,  900,   10,
 	  CONFIG_ROOT "/bouncekeys_delay" },
@@ -138,6 +138,7 @@ setup_toggles (GladeXML *dialog, GConfChangeSet *changeset)
 {
 	GObject *peditor;
 	GtkWidget *checkbox;
+	GtkWidget *checkbox_label;
 	int i = G_N_ELEMENTS (features);
 
 	while (i-- > 0) {
@@ -145,6 +146,10 @@ setup_toggles (GladeXML *dialog, GConfChangeSet *changeset)
 
 		g_return_if_fail (checkbox != NULL);
 
+		/* you can't do this from glade */
+		checkbox_label = gtk_bin_get_child (GTK_BIN (checkbox));
+		g_object_set (G_OBJECT (checkbox_label), "use_markup", TRUE, NULL);
+
 		g_object_set_data (G_OBJECT (checkbox), "dialog", dialog);
 		g_signal_connect (G_OBJECT (checkbox),
 			"toggled",
@@ -212,8 +217,6 @@ setup_ranges (GladeXML *dialog, GConfChangeSet *changeset)
 			ranges [i].step_size, 0);
 		peditor = gconf_peditor_new_numeric_range (changeset,
 			(gchar *)ranges [i].gconf_key, slide,
-			 "conv-to-widget-cb",   gconf_value_int_to_float,
-			 "conv-from-widget-cb", gconf_value_float_to_int,
 			 NULL);
 	}
 }
@@ -462,7 +465,7 @@ cb_load_CDE_file (GtkButton *button, GtkWidget *dialog)
 {
 	if (fsel == NULL) {
 		fsel = GTK_FILE_SELECTION (
-			gtk_file_selection_new (_("Select CDE AccessX file")));
+			gtk_file_selection_new (_("Import Feature Settings File")));
 
 		gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (fsel));
 		gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION (fsel), FALSE);
