@@ -512,7 +512,7 @@ struct TimeoutData {
 char *
 timeout_string (int time)
 {
-  return g_strdup_printf (_("Testing the new settings. If you don't respond in %d seconds the previous settings will be restored."), time);
+  return g_strdup_printf (ngettext ("Testing the new settings. If you don't respond in %d second the previous settings will be restored.", "Testing the new settings. If you don't respond in %d seconds the previous settings will be restored.", time), time);
 }
 
 gboolean
@@ -686,7 +686,7 @@ cb_dialog_response (GtkDialog *dialog, gint response_id, struct DisplayInfo *inf
     case GTK_RESPONSE_HELP:
       /* FIXME: This needs to be changed to the right section
        * when the docs have been written. */
-		capplet_help (GTK_WINDOW (dialog), "wgoscustdesk.xml", "goscustdesk-38");
+		capplet_help (GTK_WINDOW (dialog), "user-guide.xml", "goscustdesk-38");
       break;
     case GTK_RESPONSE_APPLY:
       save_computer = info->per_computer_check != NULL && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (info->per_computer_check));
