@@ -126,7 +126,7 @@ idle_async_func (GdkPixbuf *pixbuf,
       gtk_tree_model_get (model, &iter,
 			  META_THEME_ID_COLUMN, &test_theme_id,
 			  -1);
-      if (test_theme_id && !strcmp (theme_id, test_theme_id))
+      if (theme_id && test_theme_id && !strcmp (theme_id, test_theme_id))
 	{
 	  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 			      META_THEME_PIXBUF_COLUMN, pixbuf ? pixbuf : default_image,
@@ -289,16 +289,24 @@ load_meta_themes (GtkTreeView *tree_view,
   current_icon_theme = gconf_client_get_string (client, ICON_THEME_KEY, NULL);
   window_manager = gnome_wm_manager_get_current (gdk_display_get_default_screen (gdk_display_get_default ()));
   wm_settings.flags = GNOME_WM_SETTING_THEME;
-  if (window_manager)
+
+  if (! window_manager)
     {
-      gnome_window_manager_get_settings (window_manager, &wm_settings);
-      current_window_theme = g_strdup (wm_settings.theme);
-    }
-  else
-    {
-      current_window_theme = g_strdup (window_theme_default_name);
+      GtkWidget *dialog;
+
+      dialog = gtk_message_dialog_new (NULL,
+				       GTK_DIALOG_MODAL,
+				       GTK_MESSAGE_ERROR,
+				       GTK_BUTTONS_OK,
+				       _("The gnome-theme-manager does not know how to change the themes on the current window manager."));
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+      exit (0);
     }
 
+  gnome_window_manager_get_settings (window_manager, &wm_settings);
+  current_window_theme = g_strdup (wm_settings.theme);
+
   /* FIXME: What do we really do when there is no theme? */
   if (current_icon_theme == NULL)
     current_icon_theme = g_strdup (icon_theme_default_name);
@@ -366,8 +374,20 @@ load_meta_themes (GtkTreeView *tree_view,
 	  else
 	    model_meta_theme_info = gnome_theme_meta_info_find (name);
 	  g_free (name);
+
+	  /* The theme was removed, and we haven't removed it from the list yet. */
+	  if (model_meta_theme_info == NULL)
+	    {
+	      GtkTreeIter iter_to_remove;
+
+	      iter_to_remove = iter;
+	      valid = gtk_tree_model_iter_next (model, &iter);
+	      gtk_list_store_remove (GTK_LIST_STORE (model), &iter_to_remove);
+	  
+	      goto end_of_loop;
+	    }
 	}
-      
+
       /* start comparing values */
       if (list && valid)
 	{
@@ -397,8 +417,8 @@ load_meta_themes (GtkTreeView *tree_view,
 	  else if (compare_val == 0)
 	    {
 	      /* We reset the blurb in case it has changed */
-	      blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
-				       list_meta_theme_info->readable_name, list_meta_theme_info->comment);
+	      blurb = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+					       list_meta_theme_info->readable_name, list_meta_theme_info->comment);
 	      pixbuf = default_image;
 
 	      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
@@ -418,8 +438,8 @@ load_meta_themes (GtkTreeView *tree_view,
 	      /* we insert a new item */
 	      GtkTreeIter iter_to_prepend;
 	      gtk_list_store_insert_before (GTK_LIST_STORE (model), &iter_to_prepend, &iter);
-	      blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
-				       list_meta_theme_info->readable_name, list_meta_theme_info->comment);
+	      blurb = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+					       list_meta_theme_info->readable_name, list_meta_theme_info->comment);
 	      pixbuf = default_image;
 
 	      gtk_list_store_set (GTK_LIST_STORE (model), &iter_to_prepend,
@@ -440,8 +460,8 @@ load_meta_themes (GtkTreeView *tree_view,
 	  list_meta_theme_info = list->data;
 	  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 
-	  blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
-				   list_meta_theme_info->readable_name, list_meta_theme_info->comment);
+	  blurb = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+					   list_meta_theme_info->readable_name, list_meta_theme_info->comment);
 	  pixbuf = NULL;
 	  if (i <= MAX_ELEMENTS_BEFORE_SCROLLING)
 	    pixbuf = generate_theme_thumbnail (list_meta_theme_info, FALSE);
@@ -641,8 +661,8 @@ add_custom_row_to_meta_theme (const gchar  *current_gtk_theme,
     gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 
   /* set the values of the Custom theme. */
-  blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
-			   _("Custom theme"), _("You can save this theme by pressing the Save Theme button."));
+  blurb = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+				   _("Custom theme"), _("You can save this theme by pressing the Save Theme button."));
 
   /* Invalidate the cache because the custom theme has potentially changed */
   /* Commented out because it does odd things */
@@ -701,8 +721,8 @@ add_initial_row_to_meta_theme (void)
     gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 
   /* set the values of the Custom theme. */
-  blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
-			   _("Custom theme"), _("You can save this theme by pressing the Save Theme button."));
+  blurb = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+				   _("Custom theme"), _("You can save this theme by pressing the Save Theme button."));
 
   /* Invalidate the cache because the custom theme has potentially changed */
   /* Commented out because it does odd things */
@@ -996,7 +1016,7 @@ static void
 cb_dialog_response (GtkDialog *dialog, gint response_id)
 {
   if (response_id == GTK_RESPONSE_HELP)
-    capplet_help (GTK_WINDOW (dialog), "wgoscustdesk.xml", "goscustdesk-12");
+    capplet_help (GTK_WINDOW (dialog), "user-guide.xml", "goscustdesk-12");
   else
     gtk_main_quit ();
 }
@@ -1389,15 +1409,15 @@ main (int argc, char *argv[])
       window_theme_default_name == NULL ||
       icon_theme_default_name == NULL)
     {
-      GtkWidget *dialog;
+      GtkWidget *msg_dialog;
 
-      dialog = gtk_message_dialog_new (NULL,
+      msg_dialog = gtk_message_dialog_new (NULL,
 				       GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
 				       _("The default theme schemas could not be found on your system.  This means that you probably don't have metacity installed, or that your gconf is configured incorrectly."));
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      gtk_dialog_run (GTK_DIALOG (msg_dialog));
+      gtk_widget_destroy (msg_dialog);
       exit (0);
     }
 
