@@ -114,6 +114,22 @@ play_cb (GtkButton *button, SoundView *view)
 	if (!event->file)
 		return;
 
+	if (!strlen (event->file))      {
+		GtkWidget *md;
+		gchar *msg;
+
+		msg = _("The sound file for this event does not exist.");
+		md = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))),
+					     0,
+					     GTK_MESSAGE_ERROR,
+					     GTK_BUTTONS_CLOSE,
+					     msg);
+
+		gtk_dialog_run (GTK_DIALOG (md));
+		gtk_widget_destroy (md);
+		return ;
+	}
+
 	if ((event->file[0] == '/') || g_file_test (event->file, G_FILE_TEST_EXISTS))
 		filename = g_strdup (event->file);
 	else
@@ -285,7 +301,12 @@ sound_view_init (GtkObject *object)
 	gnome_file_entry_set_modal (GNOME_FILE_ENTRY (view->priv->entry), TRUE);
 	path = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR, "sounds/", TRUE, NULL);
 	gnome_file_entry_set_default_path (GNOME_FILE_ENTRY (view->priv->entry), path);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), view->priv->entry);
+	/*
+	 * Added gnome_file_entry_gnome_entry to following call so that the 
+	 * mnemonic widget is the GtkCombo, i.e. GnomeEntry rather than its 
+	 * contained GtkEntry. Fixes bug #126972.
+	 */ 
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (view->priv->entry)));
 	g_free (path);
 
 	g_signal_connect (G_OBJECT (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (view->priv->entry))), "changed",
